==> haskell-hie-bios-0.12.0-127-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-bios.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-9MqyXfNlNQe4AP5ks5mD6C
key:                  hie-bios-0.12.0-9MqyXfNlNQe4AP5ks5mD6C
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  5c0417d768c96b9ae8fa87c2cf285bc4
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-9MqyXfNlNQe4AP5ks5mD6C
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1
    base16-bytestring-1.0.2.0-ASFphLrgXvi67bm2qxzorY
    bytestring-0.11.5.3 co-log-core-0.3.2.5-4V3HmgoGkXErp4Ib9Tvbp
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    conduit-extra-1.3.8-CgVZWFLveL3JOQpGK40p1j
    cryptohash-sha1-0.11.101.0-24zEmBYT7AR5XuoQwLI2BZ deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-KxrHBQWVwMp2M62XitBte8
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    ghc-9.4.8 prettyprinter-1.7.1-18Jm3UFnGYW2Ifx2izjEAg
    template-haskell-2.19.0.0 temporary-1.3-9l44ZQzJSbTL0MfCqPU8eB
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unix-compat-0.7.4.1-E7DsEjXAuRTILEPpVPaZJi
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    yaml-0.11.11.2-AOYlSEsKg9dHqSBpc42qFm

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hie-bios-0.12.0-146-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-bios.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-9XHeK8HLoeP7nIXSeWEUTe
key:                  hie-bios-0.12.0-9XHeK8HLoeP7nIXSeWEUTe
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  d3b9ab4af61128129dc6f07c0c65052d
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-9XHeK8HLoeP7nIXSeWEUTe
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    base16-bytestring-1.0.2.0-1Uz6oHjhPf9KewF5fWee2u
    bytestring-0.11.5.3 co-log-core-0.3.2.5-1Xm391iqQA3JzPA3ZEW0rk
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    conduit-extra-1.3.8-1hrV1nPRDhE45dAx9zvo6P
    cryptohash-sha1-0.11.101.0-ABJXCufxSvFHV6sCEE1AN3 deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    ghc-9.4.8 prettyprinter-1.7.1-IxfK3MMc5TsGC7SkX421m7
    template-haskell-2.19.0.0 temporary-1.3-Kn2M9G1H4VS6orEei4BtCV
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unix-compat-0.7.4.1-4GSEG4F7IBa3tepmzc9c8r
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    yaml-0.11.11.2-AINh0PDgMr7KUeC4aAoheB

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
